==> nextcloud-16.0.5.tgz: nextcloud/apps/privacy/l10n/af.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privaatheid",
    "-" : "-",
    "United Arab Emirates" : "Verenigde Arabiese Emirate",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Argentina" : "Argentinië",
    "Austria" : "Oostenryk",
    "Australia" : "Australië",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegowina" : "Bosnië-Herzegowina",
    "Bangladesh" : "Bangladesj",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarye",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Brunei" : "Broenei",
    "Brazil" : "Brasilië",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoetan",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Democratic Republic of the Congo" : "Demokratiese Republiek van die Kongo",
    "Central African Republic" : "Sentraal Afrikaanse Republiek",
    "Congo" : "Kongo",
    "Switzerland" : "Switserland",
    "Cote d'Ivoire" : "Ivoorkus",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "Sjina",
    "Colombia" : "Colombië",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cyprus" : "Siprus",
    "Czech" : "Tsjaggië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djiboeti",
    "Denmark" : "Denemarke",
    "Dominican Republic" : "Dominikaanse Republiek",
    "Algeria" : "Algerië",
    "Ecuador" : "Ecuador",
    "Egypt" : "Egipte",
    "West Sahara" : "Wes-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fidji",
    "France" : "Frankryk",
    "Gabon" : "Gaboen",
    "United Kingdom" : "Verenigde Koninkryk",
    "Georgia" : "Georgië",
    "Ghana" : "Ghana",
    "Greenland" : "Groenland",
    "Gambia" : "Gambië",
    "Guinea" : "Guinee",
    "Equatorial Guinea" : "Ekwatoriaal Guinee",
    "Greece" : "Griekeland",
    "Guatemala" : "Guatemala",
    "Guinea-Bissau" : "Guinee-Bissau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Croatia" : "Kroasië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarye",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "India" : "Indië",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Ysland",
    "Italy" : "Italië",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisië",
    "Cambodia" : "Kambodja",
    "North Korea" : "Noord-Korea",
    "South Korea" : "Suid-Korea",
    "Kuwait" : "Koeweit",
    "Kazakhstan" : "Kazakstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberië",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litaue",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolië",
    "Mauritania" : "Mauritanië",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mosambiek",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieu-Kaledonië",
    "Niger" : "Niger",
    "Nigeria" : "Nigerië",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorweë",
    "Nepal" : "Nepal",
    "New Zealand" : "Nieu-Seeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Papua New Guinea" : "Papoea-Nieu-Guinee",
    "Philippines" : "Filippyne",
    "Pakistan" : "Pakistan",
    "Poland" : "Pole",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Romania" : "Roemenië",
    "Serbia" : "Serwië",
    "Russia" : "Rusland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Solomoneilande",
    "Sudan" : "Seodan",
    "Sweden" : "Swede",
    "Singapore" : "Singapoer",
    "Slovenia" : "Slowenië",
    "Slovakia" : "Slowakye",
    "Sierra Leone" : "Sierra Leone",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Suid-Soedan",
    "El Salvador" : "El Salvador",
    "Syria" : "Sirië",
    "Swaziland" : "eSwathini",
    "Chad" : "Tsjad",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadjikistan",
    "Timor-Leste" : "Oos-Timor",
    "Turkmenistan" : "Turkmenië",
    "Tunisia" : "Tunisië",
    "Turkey" : "Turkye",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzanië",
    "Ukraine" : "Oekraïne",
    "Uganda" : "Uganda",
    "United States" : "Verenigde State",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oesbekistan",
    "Venezuela" : "Venezuela",
    "Vietnam" : "Viëtnam",
    "Vanuatu" : "Vanuatu",
    "Yemen" : "Jemen",
    "South Africa" : "Suid-Afrika",
    "Zambia" : "Zambië",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "U Nextcloud-rekening",
    "Where is your data?" : "Waar is u data?",
    "Who has access to your data?" : "Wie het toegang tot u data?",
    "Privacy policy" : "Privaatheidsbeleid",
    "Read the privacy policy." : "Lees die privaatheidsbeleid.",
    "Encryption" : "Enkripsie"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.8.tgz: nextcloud/apps/privacy/l10n/af.js <==
OC.L10N.register(
    "privacy",
    {
    "Privacy" : "Privaatheid",
    "-" : "-",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Verenigde Arabiese Emirate",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua en Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Antarctica" : "Antarktika",
    "Argentina" : "Argentinië",
    "American Samoa" : "Amerikaans-Samoa",
    "Austria" : "Oostenryk",
    "Australia" : "Australië",
    "Aruba" : "Aruba",
    "Åland Islands" : "Ålandeilande",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegovina" : "Bosnië-Herzegowina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesj",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarye",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Sint Bartholomeus",
    "Bermuda" : "Bermuda",
    "Brunei" : "Broenei",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint-Eustatius en Saba",
    "Brazil" : "Brasilië",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhoetan",
    "Bouvet Island" : "Bouveteiland",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos- (Keeling-) eilande",
    "Democratic Republic of the Congo" : "Demokratiese Republiek van die Kongo",
    "Central African Republic" : "Sentraal Afrikaanse Republiek",
    "Congo" : "Kongo",
    "Switzerland" : "Switserland",
    "Cote d'Ivoire" : "Ivoorkus",
    "Cook Islands" : "Cookeilande",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "Sjina",
    "Colombia" : "Colombië",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kaap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Kerseiland",
    "Cyprus" : "Siprus",
    "Czech" : "Tsjaggië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djiboeti",
    "Denmark" : "Denemarke",
    "Dominican Republic" : "Dominikaanse Republiek",
    "Algeria" : "Algerië",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egipte",
    "West Sahara" : "Wes-Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fidji",
    "Faroe Islands" : "Faroëreilande",
    "France" : "Frankryk",
    "Gabon" : "Gaboen",
    "United Kingdom" : "Verenigde Koninkryk",
    "Grenada" : "Grenada",
    "Georgia" : "Georgië",
    "French Guiana" : "Frans-Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambië",
    "Guinea" : "Guinee",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Ekwatoriaal Guinee",
    "Greece" : "Griekeland",
    "South Georgia and the South Sandwich Islands" : "Suid-Georgië en die Suidelike Sandwicheilande",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinee-Bissau",
    "Guyana" : "Guiana",
    "Honduras" : "Honduras",
    "Hong Kong" : "Hongkong",
    "Heard Island and McDonald Islands" : "Heardeiland en McDonaldeilande",
    "Croatia" : "Kroasië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarye",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "Isle of Man" : "Man, die eiland",
    "India" : "Indië",
    "British Indian Ocean Territory" : "Britse Indiese Oseaangebied",
    "Iraq" : "Irak",
    "Iran" : "Iran",
    "Iceland" : "Ysland",
    "Italy" : "Italië",
    "Jamaica" : "Jamaika",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgisië",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Saint Kitts and Nevis" : "Sint Kitts en Nevis",
    "North Korea" : "Noord-Korea",
    "South Korea" : "Suid-Korea",
    "Kuwait" : "Koeweit",
    "Cayman Islands" : "Kaaimanseilande",
    "Kazakhstan" : "Kazakstan",
    "Laos" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Sint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberië",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litaue",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshalleilande",
    "Mali" : "Mali",
    "Myanmar" : "Mianmar",
    "Mongolia" : "Mongolië",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Noordelike Marianaeilande",
    "Mauritania" : "Mauritanië",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maledive",
    "Malawi" : "Malawi",
    "Mexico" : "Meksiko",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mosambiek",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieu-Kaledonië",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolkeiland",
    "Nigeria" : "Nigerië",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorweë",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nieu-Seeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Frans-Polinesië",
    "Papua New Guinea" : "Papoea-Nieu-Guinee",
    "Philippines" : "Filippyne",
    "Pakistan" : "Pakistan",
    "Poland" : "Pole",
    "Saint Pierre and Miquelon" : "Sint Pierre en Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Roemenië",
    "Serbia" : "Serwië",
    "Russia" : "Rusland",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Solomoneilande",
    "Seychelles" : "Seychelle",
    "Sudan" : "Seodan",
    "Sweden" : "Swede",
    "Singapore" : "Singapoer",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sint Helena, Ascension en Tristan da Cunha",
    "Slovenia" : "Slowenië",
    "Svalbard and Jan Mayen" : "Spitsbergen en Jan Mayen",
    "Slovakia" : "Slowakye",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Suid-Soedan",
    "Sao Tome and Principe" : "São Tomé en Principe",
    "El Salvador" : "El Salvador",
    "Syria" : "Sirië",
    "Swaziland" : "eSwathini",
    "Turks and Caicos Islands" : "Turks- en Caicoseilande",
    "Chad" : "Tsjad",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Oos-Timor",
    "Turkmenistan" : "Turkmenië",
    "Tunisia" : "Tunisië",
    "Tonga" : "Tonga",
    "Turkey" : "Turkye",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan" : "Taiwan",
    "Tanzania" : "Tanzanië",
    "Ukraine" : "Oekraïne",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "Klein Afgeleë Eilande van die Verenigde State van Amerika",
    "United States" : "Verenigde State",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oesbekistan",
    "Holy See" : "Vatikaanstad",
    "Saint Vincent and the Grenadines" : "Sint Vincent en die Grenadine",
    "Venezuela" : "Venezuela",
    "Virgin Islands (British)" : "Maagde-eilande (Brits)",
    "Virgin Islands (U.S.)" : "Maagde-eilande (V.S.)",
    "Vietnam" : "Viëtnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis en Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Suid-Afrika",
    "Zambia" : "Zambië",
    "Zimbabwe" : "Zimbabwe",
    "Your Nextcloud account" : "U Nextcloud-rekening",
    "Where is your data?" : "Waar is u data?",
    "Who has access to your data?" : "Wie het toegang tot u data?",
    "Privacy policy" : "Privaatheidsbeleid",
    "Read the privacy policy." : "Lees die privaatheidsbeleid.",
    "Encryption" : "Enkripsie",
    "Bosnia and Herzegowina" : "Bosnië-Herzegowina"
},
"nplurals=2; plural=(n != 1);");
